/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include "seg7.h"
#include "Display.h"
#include "my define.h"

/*----------------------------------------------------------------------------*/
/* Global CONSTANTS                                                           */
/*----------------------------------------------------------------------------*/
unsigned char DisplayBuffer[18];

/*----------------------------------------------------------------------------*/
/* Function PROTOTYPES                                                        */
/*----------------------------------------------------------------------------*/
extern void Delay(unsigned int num);

void DisplayInit(void)
{
  clk_10=0xFF16;  //LCD CLK=LS_CK
  DrvLCD_VLCDMode(E_VLCD30);
  DrvLCD_LcdDuty (E_LCD_DUTY4);
  DrvLCD_LCDBuffer(ENABLE);

  DrvLCD_IOMode(5,0xFF);  /*Set SEG1/0 to LCD mode*/
  DrvLCD_IOMode(0,0xFF);  /*Set PT6 to LCD mode*/
  DrvLCD_IOMode(1,0xFF);  /*Set PT7 to LCD mode*/
  DrvLCD_IOMode(2,0xFF);  /*Set PT8 to LCD mode*/
  DrvLCD_IOMode(3,0xFF);  /*Set PT9 to LCD mode*/
  DrvLCD_IOMode(4,0x00);  /*Set PT10 to IO mode*/
}

/*--------------------------------------------------------------------------*/
/* Clear LCD RAM Data                                                       */
/*--------------------------------------------------------------------------*/
void ClearLCDframe(void)
{
  int i=0;
  for(i=0;i<11;i++)
  {
    DisplayBuffer[i]=0x00;
  }
  RAM2LCD(DisplayBuffer,11);
}

/*----------------------------------------------------------------------------*/
/* Display HYcon Char                                                         */
/*----------------------------------------------------------------------------*/
void DisplayHYcon(void)
{
  DisplayBuffer[0]=0x00;
  DisplayBuffer[1]=Char_H;
  DisplayBuffer[2]=Char_Y;
  DisplayBuffer[3]=Char_c;
  DisplayBuffer[4]=Char_o;
  DisplayBuffer[5]=Char_n;
  DisplayBuffer[6]=0x00;
  DisplayBuffer[7]=0x00;
  DisplayBuffer[8]=0x00;
  RAM2LCD(DisplayBuffer,11);
}

/*---------------------------------------------------------------------------*/
/* LCD DISPLAY PASS                                                          */
/*---------------------------------------------------------------------------*/
void DisplayPASS(unsigned char LcdBuffer)
{
  DisplayBuffer[0]=Char_P;
  DisplayBuffer[1]=Char_A;
  DisplayBuffer[2]=Char_S;
  DisplayBuffer[3]=Char_S;
  DisplayBuffer[4]=seg[LcdBuffer/10];
  DisplayBuffer[5]=seg[LcdBuffer%10];
  DisplayBuffer[6]=0xF0;
  DisplayBuffer[7]=0x00;
  DisplayBuffer[8]=0xF0;
  RAM2LCD(DisplayBuffer,11);
}

/*----------------------------------------------------------------------------*/
/* Display RAM Data                                                           */
/*----------------------------------------------------------------------------*/
void LCD_DATA_DISPLAY(unsigned int LcdBuffer)
{
  int i;
  int8_t MINUS;

  if((LcdBuffer<0)||(LcdBuffer>0x80000000))
  {
    LcdBuffer=~LcdBuffer;
    LcdBuffer++;
    MINUS=1;
  }
  else
  {
    MINUS=0;
  }

  for(i=5;i>=0;i--)
  {
    DisplayBuffer[i]=seg[LcdBuffer%10];
    LcdBuffer=LcdBuffer/10;
  }
  if(MINUS==1)
    DisplayBuffer[6]=S_Minus;
  else
    DisplayBuffer[6]=0x00;

  RAM2LCD(DisplayBuffer,11);
}

/*----------------------------------------------------------------------------*/
/* Display RAM Data                                                           */
/*----------------------------------------------------------------------------*/
void LCD_DATA_DISPLAY_H(unsigned int LcdBuffer)
{
  int i;
  int8_t MINUS;

  if((LcdBuffer<0)||(LcdBuffer>0x80000000))
  {
    LcdBuffer=~LcdBuffer;
    LcdBuffer++;
    MINUS=1;
  }
  else
  {
    MINUS=0;
  }

  for(i=5;i>=0;i--)
  {
    DisplayBuffer[i]=seg[LcdBuffer%0x10];
    LcdBuffer=LcdBuffer/0x10;
  }
  if(MINUS==1)
    DisplayBuffer[6]=S_Minus;
  else
    DisplayBuffer[6]=0x00;

  RAM2LCD(DisplayBuffer,11);
}

/*----------------------------------------------------------------------------*/
/* LCD test                                                      */
/*----------------------------------------------------------------------------*/
void DisplayTest(void)
{
  char count1=1;
  unsigned char DataTxLen1,DataTxLen2;

  for(DataTxLen1=0;DataTxLen1<4;DataTxLen1++)
  {
    for(DataTxLen2=0;DataTxLen2<11;DataTxLen2++)
    {
      DrvLCD_WriteData (DataTxLen2,count1);
      Delay(50000);
    }
    count1=count1<<1;
  }
}

/*----------------------------------------------------------------------------*/
/* RAM Data Send to LCD                                                       */
/*----------------------------------------------------------------------------*/
void RAM2LCD(unsigned char *Buffer_Adr, unsigned char length)
{
  unsigned char DataTxLen;

  for(DataTxLen=0;DataTxLen<length;DataTxLen++)
  {
    DrvLCD_WriteData (DataTxLen,*Buffer_Adr);
    Buffer_Adr++;
  }
}
